powered by
Wrapper function to get all available 'PredictIt' tweet count markets and contract prices.
tweet_markets()
A tibble containing bid and ask data for all tweet count markets.
tibble
## Only run this example in interactive R sessions if (interactive()) { tweet_markets() }
Run the code above in your browser using DataLab